@@ -2,6 +2,7 @@
 import copy
 import filecmp
 import os
+import platform
 import numpy as np
 import pandas as pd
 import pytest
@@ -90,7 +91,7 @@ def test_idomain(mf6sfr_instance_ModflowSfr2, shellmound_model):
     assert np.array_equal(ibound, idomain)
 
 
-@pytest.mark.xfail(os.environ.get('APPVEYOR') == 'True',
+@pytest.mark.xfail(platform.system() == 'Windows',
                    reason="for some reason filecmp.cmp fails on Windows but not OSX or Linux")
 @pytest.mark.parametrize('external_files_path', ('external', None))
 def test_write(shellmound_sfrdata, mf6sfr_instance_SFRdata, outdir, external_files_path):
